@@ -185,13 +185,12 @@ class MultiClassifier:
               columns_to_scale: list = None,
               n_components: int = None):
         """
-
-        :param n_components:
-        :param columns_to_scale:
-        :param normalize:
-        :param dimensionality_reduction:
         :param X: features
         :param y: labels
+        :param n_components: This sets the number of components to keep
+        :param columns_to_scale:
+        :param normalize: Transforms input into the range [0,1] or any other range with one of MinMaxScaler, StandardScaler or RobustScaler.
+        :param dimensionality_reduction: Utilizes PCA to reduce the dimension of the training and test features
         :param strat: used to initialize stratify = y in train_test_split if True
         :param sizeOfTest: define size of test data
         :param randomState: define random state
@@ -277,7 +276,7 @@ class MultiClassifier:
                        "BalancedBaggingClassifier", "Perceptron", "NuSVC", "LGBMClassifier"]
         return model_names
 
-    def initialize(self):
+    def _initialize_(self):
         """
         It initializes all the models that we will be using in our ensemble
         """
@@ -318,7 +317,7 @@ class MultiClassifier:
 
     def _get_index(self, df, the_best):
         name = list(self.classifier_model_names())
-        MODEL = self.initialize()
+        MODEL = self._initialize_()
         df['model_names'] = name
         high = ['accuracy', 'balanced accuracy', 'f1 score', 'r2 score', 'ROC AUC', 'Test Acc', 'Test Precision',
                 'Test Recall', 'Test f1', 'Test r2', 'Test Precision Macro', 'Test Recall Macro',
@@ -442,28 +441,24 @@ class MultiClassifier:
             X_test: str = None,
             y_train: str = None,
             y_test: str = None,
-            split_data: str = None,
+            split_data=None,
             splitting: bool = False,
             kf: bool = False,
             fold: int = 5,
             excel: bool = False,
-            return_best_model: str = None,
-            return_fastest_model: bool = False,
+            return_best_model: bool = None,
             show_train_score: bool = False,
             text: bool = False,
             vectorizer: str = None,
-            ngrams: tuple = None,
-            sort: any = None
+            ngrams: tuple = None
             ) -> DataFrame:
         # If splitting is False, then do nothing. If splitting is True, then assign the values of split_data to the
         # variables X_train, X_test, y_train, and y_test
 
-        # :param sort:
-        # :param ngrams:
-        # :param n_grams:
-        # :param vectorizer:
-        # :param text:
-        # :param show_train_score:
+        # :param ngrams: It can be used when text is set to True.
+        # :param vectorizer: It can only be used when text is set to True.
+        # :param text: Set this parameter to True only if you’re working on an NLP problem.
+        # :param show_train_score: Set this parameter to True to show the train scores together with the test scores
         # :param return_fastest_model: defaults to False, set to True when you want the method to only return a dataframe
         # of the fastest model
 
@@ -565,7 +560,7 @@ class MultiClassifier:
                     and y_train is not None \
                     and y_test is not None:
                 X_tr, X_te, y_tr, y_te = X_train, X_test, y_train, y_test
-            model = self.initialize()
+            model = self._initialize_()
             names = self.classifier_model_names()
             dataframe = {}
             for i in range(len(model)):
@@ -770,17 +765,13 @@ class MultiClassifier:
             elif return_best_model is None:
                 display(df.style.highlight_max(color="yellow"))
 
-            if return_fastest_model is True:
-                # df.drop(df[df['execution time(seconds)'] == 0.0].index, axis=0, inplace=True)
-                display(f"FASTEST MODEL")
-                display(df[df["execution time(seconds)"].max()])
             write_to_excel(excel, df)
             return df
 
         elif kf is True:
 
             # Fitting the models and predicting the values of the test set.
-            KFoldModel = self.initialize()
+            KFoldModel = self._initialize_()
             names = self.classifier_model_names()
 
             if self.target_class == 'binary':
@@ -832,7 +823,7 @@ class MultiClassifier:
         """
 
         name = self.classifier_model_names()
-        MODEL = self.initialize()
+        MODEL = self._initialize_()
 
         if model is not None and best is not None:
             raise Exception('You can only use one of the two arguments.')
